View source: R/data_read_hurdle.R
| data_read_hurdle | R Documentation |
This internal function imports the data and outputs only those variables that are needed to run the hurdle model according to the information provided by the user.
data_read_hurdle(
data,
model.eff,
model.cost,
model.se,
model.sc,
se,
sc,
cov_matrix,
type,
center,
fixed_e,
fixed_c,
random_e,
random_c,
trt_lev,
trt_pos
)
data |
A data frame in which to find variables supplied in |
model.eff |
A formula expression in conventional |
model.cost |
A formula expression in conventional |
model.se |
A formula expression in conventional |
model.sc |
A formula expression in conventional |
se |
Structural value to be found in the effect data defined in |
sc |
Structural value to be found in the cost data defined in |
cov_matrix |
Covariance matrix containing all model covariates. |
type |
Type of structural value mechanism assumed, either 'SCAR' (Structural Completely At Random) or 'SAR' (Strcutural At Random). |
center |
Logical. If |
fixed_e |
Formula of the fixed effects specified in the effectiveness model. |
fixed_c |
Formula of the fixed effects specified in the cost model. |
random_e |
Formula of the random effects specified in the effectiveness model. |
random_c |
Formula of the random effects specified in the cost model. |
trt_lev |
Levels of the treatment indicator factor. |
trt_pos |
Numeric position of the treatment indicator within the model formula. |
#Internal function only
#no examples
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.