View source: R/plot.missingHE.R
| plot.missingHE | R Documentation |
missingHEProduces a plot of the observed and imputed values (with credible intervals) for the effect and cost outcomes from a
Bayesian cost-effectiveness analysis model with two treatment arms, implemented using the function selection, pattern,
hurdle or lmdm.
The graphical layout is obtained from the functions contained in the package ggplot2 and ggthemes.
## S3 method for class 'missingHE'
plot(
x,
prob = c(0.025, 0.975),
class = "scatter",
outcome = "both",
trt = "all",
time_plot = NULL,
theme = NULL,
only.plot = TRUE,
...
)
x |
A |
prob |
A numeric vector of probabilities representing the upper and lower CI sample quantiles to be calculated and returned for the imputed values. |
class |
Type of the plot comparing the observed and imputed outcome data. Available choices are 'scatter' (default), 'histogram' and 'boxplot' for a scatter, histogram or a boxplot of the observed and average imputed outcome data, respectively. |
outcome |
The outcome variables that should be displayed. Options are: 'both' (default) for both effects and costs; 'effects' or 'costs' for the effects or costs separately. |
trt |
treatment group for which plots should be displayed. Choices include: 'all' (default) for all groups; 'none' for results across all groups; any character or numeric value denoting the treatment group name or index associated with the treatment variable in the original data set. |
time_plot |
Time point for which the graphs should be displayed. |
theme |
Type of ggplot theme among some pre-defined themes, mostly taken from the package ggthemes. For a full list of available themes see details. |
only.plot |
Logical. If |
... |
Additional parameters that can be provided to manage the output of |
The function produces a plot of the observed and imputed effect and cost data in a two-arm based
cost-effectiveness model implemented using the function selection, pattern, hurdle or or lmdm.
The purpose of this graph is to visually compare the outcome values for the fully-observed individuals with those imputed by the model for the missing individuals.
For scatter plots, average imputed values are also associated with credible intervals specified in the argument prob.
The argument theme allows to customise the graphical aspect of the plots generated by plot.missingHE and
allows to choose among a set of possible pre-defined themes taken form the package ggtheme. For a complete list of the available character names
for each theme and scheme set, see ggthemes and bayesplot.
A ggplot object containing the plots specified in the argument class.
Andrea Gabrio
Daniels, MJ. Hogan, JW. (2008) Missing Data in Longitudinal Studies: strategies for Bayesian modelling and sensitivity analysis, CRC/Chapman Hall.
Molenberghs, G. Fitzmaurice, G. Kenward, MG. Tsiatis, A. Verbeke, G. (2015) Handbook of Missing Data Methodology, CRC/Chapman Hall.
selection pattern hurdle lmdm diagnostic
# For examples see the function \code{\link{selection}}, \code{\link{pattern}},
# \code{\link{hurdle}} or \code{\link{lmdm}}
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.