print.missingHE: Print method for the posterior results contained in the...

View source: R/print.missingHE.R

print.missingHER Documentation

Print method for the posterior results contained in the objects of class missingHE

Description

Prints the summary table for the model fitted, with the estimate of the parameters and/or missing values.

Usage

## S3 method for class 'missingHE'
print(x, display = "fixed", digits = 3, ...)

Arguments

x

A missingHE object containing the results of the Bayesian model run using the function selection, pattern, hurdle or lmdm.

display

Set of parameters for which posterior summaries are displayed. Choices are: fixed effects ('fixed'), random effects ('random'), individual log likelihood values ('loglik'), individual conditional parameter values ('conditional') and individual imputed values ('mis').

digits

Integer indicating the number of decimal places to be used for rounding (default = 3).

...

additional arguments affecting the output produced. For example: param = JAGS name assigned to the specific model parameters to be shown in the printed table.

Author(s)

Andrea Gabrio

Examples

 
# For examples see the function \code{\link{selection}}, \code{\link{pattern}}, 
# \code{\link{hurdle}} or \code{\link{lmdm}}
# 
# 

missingHE documentation built on March 19, 2026, 5:06 p.m.