run_pattern: An internal function to execute a JAGS pattern mixture model...

View source: R/run_pattern.R

run_patternR Documentation

An internal function to execute a JAGS pattern mixture model and get posterior results

Description

This function fits a JAGS using the jags function and obtain posterior inferences.

Usage

run_pattern(data_model, type, dist_e, dist_c, model_info)

Arguments

data_model

list containing the data for the model to be passed to JAGS.

type

Type of missingness mechanism assumed. Choices are Missing At Random (MAR), Missing Not At Random for the effects (MNAR_eff), Missing Not At Random for the costs (MNAR_cost), and Missing Not At Random for both (MNAR).

dist_e

distribution assumed for the effects. Current available choices are: Normal ('norm'), Beta ('beta'), Gamma ('gamma'), Exponential ('exp'), Weibull ('weib'), Logistic ('logis'), Poisson ('pois'), Negative Binomial ('negbin') or Bernoulli ('bern').

dist_c

Distribution assumed for the costs. Current available choices are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm').

model_info

list containing model and MCMC information to be passed to JAGS.

Examples

#Internal function only
#No examples
#
#

missingHE documentation built on March 19, 2026, 5:06 p.m.