View source: R/coef.missingHE.R
| coef.missingHE | R Documentation |
missingHEProduces a table printout with summary statistics for the regression coefficients of the health economic evaluation probabilistic model
run using the function selection, pattern, hurdle or lmdm.
## S3 method for class 'missingHE'
coef(object, prob = c(0.025, 0.975), random = FALSE, digits = 3, ...)
object |
A |
prob |
A numeric vector of probabilities within the range (0,1), representing the upper and lower CI sample quantiles to be calculated and returned for the estimates. |
random |
Logical. If |
digits |
Integer indicating the number of decimal places to be used for rounding (default = 3). |
... |
Additional arguments affecting the summary produced. |
Prints a table with some summary statistics, including posterior mean, standard deviation and lower and upper quantiles based on the
values specified in prob, for the posterior distributions of the regression coefficients of the effects and costs models run using the
function selection, pattern, hurdle or lmdm.
Andrea Gabrio
selection pattern hurdle lmdm diagnostic plot.missingHE
# For examples see the function \code{\link{selection}}, \code{\link{pattern}},
# \code{\link{hurdle}} or \code{\link{lmdm}}
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.