View source: R/data_read_lmdm.R
| data_read_lmdm | R Documentation |
This internal function imports the data and outputs only those variables that are needed to run the model according to the information provided by the user.
data_read_lmdm(
data,
model.eff,
model.cost,
model.me,
model.mc,
cov_matrix,
type,
center,
fixed_e,
fixed_c,
random_e,
random_c,
trt_lev,
trt_pos
)
data |
A data frame in which to find variables supplied in |
model.eff |
A formula expression in conventional |
model.cost |
A formula expression in conventional |
model.me |
A formula expression in conventional |
model.mc |
A formula expression in conventional R linear modelling syntax. The response must be indicated with the
term 'mc'(missing costs) and any covariates used to estimate the probability of missing costs should be given on the right-hand side.
If there are no covariates, specify |
cov_matrix |
Data frame containing the covariate matrix of the model. |
type |
Type of missingness mechanism assumed. Choices are Missing At Random (MAR) and Missing Not At Random (MNAR). |
center |
Logical. If |
fixed_e |
Fixed effects variables to be included in the effects model |
fixed_c |
Fixed effects variables to be included in the costs model |
random_e |
Random effects variables to be included in the effects model |
random_c |
Random effects variables to be included in the costs model |
trt_lev |
Vector of names of each treatment factor level |
trt_pos |
Vector of name indices of each treatment factor level |
#Internal function only
#no examples
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.