View source: R/print.missingHE.R
| print.missingHE | R Documentation |
missingHEPrints the summary table for the model fitted, with the estimate of the parameters and/or missing values.
## S3 method for class 'missingHE'
print(x, display = "fixed", digits = 3, ...)
x |
A |
display |
Set of parameters for which posterior summaries are displayed. Choices are: fixed effects ('fixed'), random effects ('random'), individual log likelihood values ('loglik'), individual conditional parameter values ('conditional') and individual imputed values ('mis'). |
digits |
Integer indicating the number of decimal places to be used for rounding (default = 3). |
... |
additional arguments affecting the output produced. For example: |
Andrea Gabrio
# For examples see the function \code{\link{selection}}, \code{\link{pattern}},
# \code{\link{hurdle}} or \code{\link{lmdm}}
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.