| run_hurdle | R Documentation |
This function fits a JAGS using the jags function and obtain posterior inferences.
run_hurdle(data_model, type, dist_e, dist_c, model_info)
data_model |
list containing the data for the model to be passed to JAGS. |
type |
Type of structural value mechanism assumed. Choices are Structural Completely At Random (SCAR), Structural At Random (SAR), |
dist_e |
distribution assumed for the effects. Current available choices are: Normal ('norm'), Beta ('beta'), Gamma ('gamma'), Exponential ('exp'), Weibull ('weib'), Logistic ('logis'), Poisson ('pois'), Negative Binomial ('negbin') or Bernoulli ('bern'). |
dist_c |
Distribution assumed for the costs. Current available choices are: Normal ('norm'), Gamma ('gamma') or LogNormal ('lnorm'). |
model_info |
list containing model and MCMC information to be passed to JAGS. |
#Internal function only
#No examples
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.