View source: R/summary.missingHE.R
| summary.missingHE | R Documentation |
missingHEProduces a table printout with some summary results of the health economic evaluation probabilistic model
run using the function selection, pattern, hurdle or lmdm.
## S3 method for class 'missingHE'
summary(object, incremental = FALSE, prob = c(0.025, 0.975), digits = 3, ...)
object |
A |
incremental |
Logical. If |
prob |
A numeric vector of probabilities within the range (0, 1), representing the upper and lower CI quantiles to be calculated and returned for the posterior estimates. |
digits |
Integer indicating the number of decimal places to be used for rounding (default = 3). |
... |
Additional arguments affecting the summary produced. |
Prints tables with information on the CE results based on a model fitted using the function selection, pattern or hurdle.
Summary information on the main parameters of interests is provided.
Andrea Gabrio
Baio, G.(2012). Bayesian Methods in Health Economcis. CRC/Chapman Hall, London.
selection pattern hurdle lmdm diagnostic plot.missingHE
# For examples see the function selection, pattern or hurdle
#
#
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.